pub fn create_range_reader(source: &str) -> AnyResult<Arc<dyn RangeReader>>Expand description
Create a range reader from a path or URL
pub fn create_range_reader(source: &str) -> AnyResult<Arc<dyn RangeReader>>Create a range reader from a path or URL